@@ -411,15 +411,28 @@ brasero_job_check_output_disc_space (BraseroJob *self,
 	/* This is not really an error, we'll probably ask the 
 	 * user to load a new disc */
 	if (output_blocks > media_blocks) {
+		gchar *media_blocks_str;
+		gchar *output_blocks_str;
+
 		BRASERO_BURN_LOG ("Insufficient space on disc %"G_GINT64_FORMAT"/%"G_GINT64_FORMAT,
 				  media_blocks,
 				  output_blocks);
+
+		media_blocks_str = g_strdup_printf ("%"G_GINT64_FORMAT, media_blocks);
+		output_blocks_str = g_strdup_printf ("%"G_GINT64_FORMAT, output_blocks);
+
 		g_set_error (error,
 			     BRASERO_BURN_ERROR,
 			     BRASERO_BURN_ERROR_MEDIUM_SPACE,
-			     _("Not enough space available on the disc (%"G_GINT64_FORMAT" available for %"G_GINT64_FORMAT")"),
-			     media_blocks,
-			     output_blocks);
+			     /* Translators: the first %s is the size of the free space on the medium
+			      * and the second %s is the size of the space required by the data to be
+			      * burnt. */
+			     _("Not enough space available on the disc (%s available for %s)"),
+			     media_blocks_str,
+			     output_blocks_str);
+
+		g_free (media_blocks_str);
+		g_free (output_blocks_str);
 		return BRASERO_BURN_NEED_RELOAD;
 	}
 
@@ -626,36 +639,6 @@ brasero_job_set_output_file (BraseroJob *self,
 				priv->output->toc = toc;
 				return BRASERO_BURN_OK;
 			}
-
-			/* There must be an image at least */
-			if ((flags & BRASERO_BURN_FLAG_DONT_OVERWRITE)
-			&&   g_file_test (image, G_FILE_TEST_EXISTS)) {
-				BRASERO_BURN_LOG ("Problem with image existence");
-				g_set_error (error,
-					     BRASERO_BURN_ERROR,
-					     BRASERO_BURN_ERROR_GENERAL,
-					     _("\"%s\" already exists"),
-					     image);
-				g_free (toc);
-				g_free (image);
-				return BRASERO_BURN_ERR;
-			}
-
-			if (priv->type.subtype.img_format != BRASERO_IMAGE_FORMAT_BIN) {
-				/* There must a toc file in this case */
-				if ((flags & BRASERO_BURN_FLAG_DONT_OVERWRITE)
-				&&   g_file_test (toc, G_FILE_TEST_EXISTS)) {
-					BRASERO_BURN_LOG ("Problem with toc existence");
-					g_set_error (error,
-						     BRASERO_BURN_ERROR,
-						     BRASERO_BURN_ERROR_GENERAL,
-						     _("\"%s\" already exists"),
-						     toc);
-					g_free (toc);
-					g_free (image);
-					return BRASERO_BURN_ERR;
-				}
-			}
 		}
 		else {
 			/* NOTE: no need to check for the existence here */
