@@ -42,8 +42,6 @@
 #include <glib/gi18n-lib.h>
 #include <gdk/gdk.h>
 
-#include "burn-basics.h"
-
 #include "brasero-media-private.h"
 
 #include "brasero-medium.h"
@@ -81,11 +79,7 @@ const gchar *types [] = {	N_("File"),
 				N_("Rewritable Blu-ray disc"),
 				NULL };
 
-typedef enum {
-	BRASERO_MEDIUM_CAP_INVALID	= 0,
-	BRASERO_MEDIUM_CAP_TRUE		= 1,
-	BRASERO_MEDIUM_CAP_FALSE		= 2
-} BraseroMediumCapState;
+
 
 typedef struct _BraseroMediumPrivate BraseroMediumPrivate;
 struct _BraseroMediumPrivate
@@ -99,17 +93,17 @@ struct _BraseroMediumPrivate
 
 	gchar *id;
 
-	gint max_rd;
-	gint max_wrt;
+	guint max_rd;
+	guint max_wrt;
 
-	gint *rd_speeds;
-	gint *wr_speeds;
+	guint *rd_speeds;
+	guint *wr_speeds;
 
-	gint64 block_num;
-	gint64 block_size;
+	goffset block_num;
+	goffset block_size;
 
 	guint first_open_track;
-	guint64 next_wr_add;
+	goffset next_wr_add;
 
 	BraseroMedia info;
 	BraseroDrive *drive;
@@ -117,9 +111,9 @@ struct _BraseroMediumPrivate
 	gchar *CD_TEXT_title;
 
 	/* Do we really need both? */
-	guint dummy_sao:2;
-	guint dummy_tao:2;
-	guint burnfree:2;
+	guint dummy_sao:1;
+	guint dummy_tao:1;
+	guint burnfree:1;
 
 	guint probe_cancelled:1;
 };
@@ -151,8 +145,8 @@ typedef struct _BraseroMediumTrack BraseroMediumTrack;
 struct _BraseroMediumTrack {
 	guint session;
 	BraseroMediumTrackType type;
-	guint64 start;
-	guint64 blocks_num;
+	goffset start;
+	goffset blocks_num;
 };
 
 enum
@@ -171,76 +165,6 @@ static gulong medium_signals [LAST_SIGNAL] = {0, };
 
 static GObjectClass* parent_class = NULL;
 
-/**
- * This one is not supposed to be public API. It's declared in burn-caps.c
- */
-
-BraseroBurnFlag
-brasero_medium_supported_flags (BraseroMedium *self,
-				BraseroBurnFlag flags)
-{
-	BraseroMediumPrivate *priv;
-
-	priv = BRASERO_MEDIUM_PRIVATE (self);
-
-	/* This is always FALSE */
-	if (priv->info & BRASERO_MEDIUM_PLUS)
-		flags &= ~BRASERO_BURN_FLAG_DUMMY;
-	/* Simulation is only possible according to write modes. This mode is
-	 * mostly used by cdrecord/wodim for CLONE images. */
-	else if (priv->info & BRASERO_MEDIUM_DVD) {
-		if (priv->dummy_sao != BRASERO_MEDIUM_CAP_TRUE)
-			flags &= ~BRASERO_BURN_FLAG_DUMMY;
-	}
-	else if (flags & BRASERO_BURN_FLAG_DAO) {
-		if (priv->dummy_sao != BRASERO_MEDIUM_CAP_TRUE)
-			flags &= ~BRASERO_BURN_FLAG_DUMMY;
-	}
-	else if (priv->dummy_tao != BRASERO_MEDIUM_CAP_TRUE)
-		flags &= ~BRASERO_BURN_FLAG_DUMMY;
-
-	if (!priv->burnfree)
-		flags &= ~BRASERO_BURN_FLAG_BURNPROOF;
-
-	return flags;
-}
-
-/**
- * This one is not supposed to be public API. It's declared in burn-caps.c
- */
-
-gboolean
-brasero_medium_support_flags (BraseroMedium *self,
-			      BraseroBurnFlag flags)
-{
-	BraseroMediumPrivate *priv;
-
-	priv = BRASERO_MEDIUM_PRIVATE (self);
-
-	if (flags & BRASERO_BURN_FLAG_DUMMY) {
-		/* This is always FALSE */
-		if (priv->info & BRASERO_MEDIUM_PLUS)
-			return FALSE;
-
-		if (priv->info & BRASERO_MEDIUM_DVD) {
-			if (priv->dummy_sao != BRASERO_MEDIUM_CAP_TRUE)
-				return FALSE;
-		}
-		else if (flags & BRASERO_BURN_FLAG_DAO) {
-			if (priv->dummy_sao != BRASERO_MEDIUM_CAP_TRUE)
-				return FALSE;
-		}
-		else if (priv->dummy_tao != BRASERO_MEDIUM_CAP_TRUE)
-			return FALSE;
-	}
-
-	if (flags & BRASERO_BURN_FLAG_BURNPROOF) {
-		if (!priv->burnfree)
-			return FALSE;
-	}
-
-	return TRUE;
-}
 
 /**
  * brasero_medium_get_tooltip:
@@ -366,8 +290,8 @@ brasero_medium_get_status (BraseroMedium *medium)
 /**
  * brasero_medium_get_last_data_track_address:
  * @medium: #BraseroMedium
- * @byte: a #gint64 * or NULL
- * @sector: a #gint64 * or NULL
+ * @byte: a #goffset * or NULL
+ * @sector: a #goffset * or NULL
  *
  * Stores in either @byte (in bytes) or in @sector (in blocks) the address where
  * the last session starts. This is useful when creating a multisession image or
@@ -376,8 +300,8 @@ brasero_medium_get_status (BraseroMedium *medium)
  **/
 gboolean
 brasero_medium_get_last_data_track_address (BraseroMedium *medium,
-					    gint64 *byte,
-					    gint64 *sector)
+					    goffset *bytes,
+					    goffset *sectors)
 {
 	GSList *iter;
 	BraseroMediumPrivate *priv;
@@ -396,19 +320,14 @@ brasero_medium_get_last_data_track_address (BraseroMedium *medium,
 			track = current;
 	}
 
-	if (!track) {
-		if (byte)
-			*byte = -1;
-		if (sector)
-			*sector = -1;
+	if (!track)
 		return FALSE;
-	}
 
-	if (byte)
-		*byte = track->start * priv->block_size;
+	if (bytes)
+		*bytes = track->start * priv->block_size;
 
-	if (sector)
-		*sector = track->start;
+	if (sectors)
+		*sectors = track->start;
 
 	return TRUE;
 }
@@ -416,8 +335,8 @@ brasero_medium_get_last_data_track_address (BraseroMedium *medium,
 /**
  * brasero_medium_get_last_data_track_space:
  * @medium: #BraseroMedium
- * @size: a #gint64 * or NULL
- * @blocks: a #gint64 * or NULL
+ * @size: a #goffset * or NULL
+ * @blocks: a #goffset * or NULL
  *
  * Stores in either @size (in bytes) or in @blocks (in blocks) the space used by
  * the last track on the medium.
@@ -425,8 +344,8 @@ brasero_medium_get_last_data_track_address (BraseroMedium *medium,
  **/
 gboolean
 brasero_medium_get_last_data_track_space (BraseroMedium *medium,
-					  gint64 *size,
-					  gint64 *blocks)
+					  goffset *bytes,
+					  goffset *sectors)
 {
 	GSList *iter;
 	BraseroMediumPrivate *priv;
@@ -446,17 +365,17 @@ brasero_medium_get_last_data_track_space (BraseroMedium *medium,
 	}
 
 	if (!track) {
-		if (size)
-			*size = -1;
-		if (blocks)
-			*blocks = -1;
+		if (bytes)
+			*bytes = 0;
+		if (sectors)
+			*sectors = 0;
 		return FALSE;
 	}
 
-	if (size)
-		*size = track->blocks_num * priv->block_size;
-	if (blocks)
-		*blocks = track->blocks_num;
+	if (bytes)
+		*bytes = track->blocks_num * priv->block_size;
+	if (sectors)
+		*sectors = track->blocks_num;
 
 	return TRUE;
 }
@@ -524,8 +443,8 @@ brasero_medium_get_track (BraseroMedium *medium,
  * brasero_medium_get_track_space:
  * @medium: a #BraseroMedium
  * @num: a #guint
- * @size: a #gint64 * or NULL
- * @blocks: a #gint64 * or NULL
+ * @size: a #goffset * or NULL
+ * @blocks: a #goffset * or NULL
  *
  * Stores in either @size (in bytes) or in @blocks (in blocks) the space used
  * by session @num on the disc.
@@ -537,8 +456,8 @@ brasero_medium_get_track (BraseroMedium *medium,
 gboolean
 brasero_medium_get_track_space (BraseroMedium *medium,
 				guint num,
-				gint64 *size,
-				gint64 *blocks)
+				goffset *bytes,
+				goffset *sectors)
 {
 	BraseroMediumPrivate *priv;
 	BraseroMediumTrack *track;
@@ -550,17 +469,17 @@ brasero_medium_get_track_space (BraseroMedium *medium,
 
 	track = brasero_medium_get_track (medium, num);
 	if (!track) {
-		if (size)
-			*size = -1;
-		if (blocks)
-			*blocks = -1;
+		if (bytes)
+			*bytes = 0;
+		if (sectors)
+			*sectors = 0;
 		return FALSE;
 	}
 
-	if (size)
-		*size = track->blocks_num * priv->block_size;
-	if (blocks)
-		*blocks = track->blocks_num;
+	if (bytes)
+		*bytes = track->blocks_num * priv->block_size;
+	if (sectors)
+		*sectors = track->blocks_num;
 
 	return TRUE;
 }
@@ -569,8 +488,8 @@ brasero_medium_get_track_space (BraseroMedium *medium,
  * brasero_medium_get_track_address:
  * @medium: a #BraseroMedium
  * @num: a #guint
- * @byte: a #gint64 * or NULL
- * @sector: a #gint64 * or NULL
+ * @byte: a #goffset * or NULL
+ * @sector: a #goffset * or NULL
  *
  * Stores in either @byte (in bytes) or in @sector (in blocks) the address at
  * which the session identified by @num starts.
@@ -582,8 +501,8 @@ brasero_medium_get_track_space (BraseroMedium *medium,
 gboolean
 brasero_medium_get_track_address (BraseroMedium *medium,
 				  guint num,
-				  gint64 *byte,
-				  gint64 *sector)
+				  goffset *bytes,
+				  goffset *sectors)
 {
 	BraseroMediumPrivate *priv;
 	BraseroMediumTrack *track;
@@ -595,17 +514,17 @@ brasero_medium_get_track_address (BraseroMedium *medium,
 
 	track = brasero_medium_get_track (medium, num);
 	if (!track) {
-		if (byte)
-			*byte = -1;
-		if (sector)
-			*sector = -1;
+		if (bytes)
+			*bytes = 0;
+		if (sectors)
+			*sectors = 0;
 		return FALSE;
 	}
 
-	if (byte)
-		*byte = track->start * priv->block_size;
-	if (sector)
-		*sector = track->start;
+	if (bytes)
+		*bytes = track->start * priv->block_size;
+	if (sectors)
+		*sectors = track->start;
 
 	return TRUE;	
 }
@@ -656,10 +575,10 @@ brasero_medium_get_next_writable_address (BraseroMedium *medium)
  * Gets the maximum speed that can be used to write to @medium.
  * Note: the speed are in B/sec.
  *
- * Return value: a #gint64.
+ * Return value: a #guint64.
  *
  **/
-gint64
+guint64
 brasero_medium_get_max_write_speed (BraseroMedium *medium)
 {
 	BraseroMediumPrivate *priv;
@@ -678,14 +597,14 @@ brasero_medium_get_max_write_speed (BraseroMedium *medium)
  * Gets an array holding all possible speeds to write to @medium.
  * Note: the speed are in B/sec.
  *
- * Return value: a #gint64 *.
+ * Return value: a #guint64 *.
  *
  **/
-gint64 *
+guint64 *
 brasero_medium_get_write_speeds (BraseroMedium *medium)
 {
 	BraseroMediumPrivate *priv;
-	gint64 *speeds;
+	guint64 *speeds;
 	guint max = 0;
 	guint i;
 
@@ -699,7 +618,7 @@ brasero_medium_get_write_speeds (BraseroMedium *medium)
 
 	while (priv->wr_speeds [max] != 0) max ++;
 
-	speeds = g_new0 (gint64, max + 1);
+	speeds = g_new0 (guint64, max + 1);
 
 	/* NOTE: about the following, it's not KiB here but KB */
 	for (i = 0; i < max; i ++)
@@ -735,7 +654,7 @@ brasero_medium_get_write_speeds (BraseroMedium *medium)
 /**
  * brasero_medium_get_data_size:
  * @medium: #BraseroMedium
- * @size: a #gint64 * or NULL
+ * @bytes: a #gint64 * or NULL
  * @blocks: a #gint64 * or NULL
  *
  * Stores in either @size (in bytes) or @blocks (the number of blocks) the size
@@ -744,7 +663,7 @@ brasero_medium_get_write_speeds (BraseroMedium *medium)
  **/
 void
 brasero_medium_get_data_size (BraseroMedium *medium,
-			      gint64 *size,
+			      gint64 *bytes,
 			      gint64 *blocks)
 {
 	GSList *iter;
@@ -758,8 +677,8 @@ brasero_medium_get_data_size (BraseroMedium *medium,
 
 	if (!priv->tracks) {
 		/* that's probably because it wasn't possible to retrieve info */
-		if (size)
-			*size = 0;
+		if (bytes)
+			*bytes = 0;
 
 		if (blocks)
 			*blocks = 0;
@@ -777,8 +696,8 @@ brasero_medium_get_data_size (BraseroMedium *medium,
 		track = iter->data;
 	}
 
-	if (size)
-		*size = track ? (track->start + track->blocks_num) * priv->block_size: 0;
+	if (bytes)
+		*bytes = track ? (track->start + track->blocks_num) * priv->block_size: 0;
 
 	if (blocks)
 		*blocks = track ? track->start + track->blocks_num: 0;
@@ -787,7 +706,7 @@ brasero_medium_get_data_size (BraseroMedium *medium,
 /**
  * brasero_medium_get_free_space:
  * @medium: #BraseroMedium
- * @size: a #gint64 * or NULL
+ * @bytes: a #gint64 * or NULL
  * @blocks: a #gint64 * or NULL
  *
  * Stores in either @size (in bytes) or @blocks (the number of blocks) the space
@@ -796,7 +715,7 @@ brasero_medium_get_data_size (BraseroMedium *medium,
  **/
 void
 brasero_medium_get_free_space (BraseroMedium *medium,
-			       gint64 *size,
+			       gint64 *bytes,
 			       gint64 *blocks)
 {
 	GSList *iter;
@@ -813,15 +732,15 @@ brasero_medium_get_free_space (BraseroMedium *medium,
 		 * maybe it also happens with unformatted DVD+RW */
 
 		if (priv->info & BRASERO_MEDIUM_CLOSED) {
-			if (size)
-				*size = 0;
+			if (bytes)
+				*bytes = 0;
 
 			if (blocks)
 				*blocks = 0;
 		}
 		else {
-			if (size)
-				*size = priv->block_num * priv->block_size;
+			if (bytes)
+				*bytes = priv->block_num * priv->block_size;
 
 			if (blocks)
 				*blocks = priv->block_num;
@@ -840,16 +759,16 @@ brasero_medium_get_free_space (BraseroMedium *medium,
 		}
 	}
 
-	if (size) {
+	if (bytes) {
 		if (!track) {
 			/* No leadout was found so the disc is probably closed:
 			 * no free space left. */
-			*size = 0;
+			*bytes = 0;
 		}
 		else if (track->blocks_num <= 0)
-			*size = (priv->block_num - track->start) * priv->block_size;
+			*bytes = (priv->block_num - track->start) * priv->block_size;
 		else
-			*size = track->blocks_num * priv->block_size;
+			*bytes = track->blocks_num * priv->block_size;
 	}
 
 	if (blocks) {
@@ -868,7 +787,7 @@ brasero_medium_get_free_space (BraseroMedium *medium,
 /**
  * brasero_medium_get_capacity:
  * @medium: #BraseroMedium
- * @size: a #gint64 * or NULL
+ * @bytes: a #gint64 * or NULL
  * @blocks: a #gint64 * or NULL
  *
  * Stores in either @size (in bytes) or @blocks (the number of blocks) the total
@@ -879,7 +798,7 @@ brasero_medium_get_free_space (BraseroMedium *medium,
  **/
 void
 brasero_medium_get_capacity (BraseroMedium *medium,
-			     gint64 *size,
+			     gint64 *bytes,
 			     gint64 *blocks)
 {
 	BraseroMediumPrivate *priv;
@@ -890,24 +809,24 @@ brasero_medium_get_capacity (BraseroMedium *medium,
 	priv = BRASERO_MEDIUM_PRIVATE (medium);
 
 	if (priv->info & BRASERO_MEDIUM_REWRITABLE) {
-		if (size)
-			*size = priv->block_num * priv->block_size;
+		if (bytes)
+			*bytes = priv->block_num * priv->block_size;
 
 		if (blocks)
 			*blocks = priv->block_num;
 	}
 	else  if (priv->info & BRASERO_MEDIUM_CLOSED)
-		brasero_medium_get_data_size (medium, size, blocks);
+		brasero_medium_get_data_size (medium, bytes, blocks);
 	else
-		brasero_medium_get_free_space (medium, size, blocks);
+		brasero_medium_get_free_space (medium, bytes, blocks);
 }
 
 /**
  * Test presence of simulate burning
  */
 
-static BraseroBurnResult
-brasero_medium_test_simulate_CD_SAO (BraseroMedium *self,
+static gboolean
+brasero_medium_test_simulate_CD_TAO (BraseroMedium *self,
 				     BraseroDeviceHandle *handle,
 				     BraseroScsiErrCode *code)
 {
@@ -929,7 +848,7 @@ brasero_medium_test_simulate_CD_SAO (BraseroMedium *self,
 							 code);
 	if (result != BRASERO_SCSI_OK) {
 		BRASERO_MEDIA_LOG ("GET CONFIGURATION failed");
-		return BRASERO_BURN_ERR;
+		return FALSE;
 	}
 
 	desc = hdr->desc;
@@ -937,14 +856,14 @@ brasero_medium_test_simulate_CD_SAO (BraseroMedium *self,
 		BRASERO_MEDIA_LOG ("Feature is not current");
 
 	tao_desc = (BraseroScsiCDTAODesc *) desc->data;
-	priv->dummy_tao = tao_desc->dummy ? BRASERO_MEDIUM_CAP_TRUE:BRASERO_MEDIUM_CAP_FALSE;
-	priv->burnfree = tao_desc->buf ? BRASERO_MEDIUM_CAP_TRUE:BRASERO_MEDIUM_CAP_FALSE;
+	priv->dummy_tao = tao_desc->dummy != 0;
+	priv->burnfree = tao_desc->buf != 0;
 	g_free (hdr);
-	return BRASERO_BURN_OK;
+	return TRUE;
 }
 
-static BraseroBurnResult
-brasero_medium_test_simulate_CD_TAO (BraseroMedium *self,
+static gboolean
+brasero_medium_test_simulate_CD_SAO (BraseroMedium *self,
 				     BraseroDeviceHandle *handle,
 				     BraseroScsiErrCode *code)
 {
@@ -965,7 +884,7 @@ brasero_medium_test_simulate_CD_TAO (BraseroMedium *self,
 							 code);
 	if (result != BRASERO_SCSI_OK) {
 		BRASERO_MEDIA_LOG ("GET CONFIGURATION failed");
-		return BRASERO_BURN_ERR;
+		return FALSE;
 	}
 
 	desc = hdr->desc;
@@ -973,13 +892,13 @@ brasero_medium_test_simulate_CD_TAO (BraseroMedium *self,
 		BRASERO_MEDIA_LOG ("Feature is not current");
 
 	sao_desc = (BraseroScsiCDSAODesc *) desc->data;
-	priv->dummy_sao = sao_desc->dummy ? BRASERO_MEDIUM_CAP_TRUE:BRASERO_MEDIUM_CAP_FALSE;
-	priv->burnfree = sao_desc->buf ? BRASERO_MEDIUM_CAP_TRUE:BRASERO_MEDIUM_CAP_FALSE;
+	priv->dummy_sao = sao_desc->dummy != 0;
+	priv->burnfree = sao_desc->buf != 0;
 	g_free (hdr);
-	return BRASERO_BURN_OK;
+	return TRUE;
 }
 
-static BraseroBurnResult
+static gboolean
 brasero_medium_test_simulate_DVDRW (BraseroMedium *self,
 				    BraseroDeviceHandle *handle,
 				    BraseroScsiErrCode *code)
@@ -1002,7 +921,7 @@ brasero_medium_test_simulate_DVDRW (BraseroMedium *self,
 							 code);
 	if (result != BRASERO_SCSI_OK) {
 		BRASERO_MEDIA_LOG ("GET CONFIGURATION failed");
-		return BRASERO_BURN_ERR;
+		return FALSE;
 	}
 
 	desc = hdr->desc;
@@ -1010,11 +929,11 @@ brasero_medium_test_simulate_DVDRW (BraseroMedium *self,
 		BRASERO_MEDIA_LOG ("Feature is not current");
 
 	less_wrt_desc = (BraseroScsiDVDRWlessWrtDesc *) desc->data;
-	priv->dummy_sao = less_wrt_desc->dummy ? BRASERO_MEDIUM_CAP_TRUE:BRASERO_MEDIUM_CAP_FALSE;
-	priv->dummy_tao = less_wrt_desc->dummy ? BRASERO_MEDIUM_CAP_TRUE:BRASERO_MEDIUM_CAP_FALSE;
-	priv->burnfree = less_wrt_desc->buf ? BRASERO_MEDIUM_CAP_TRUE:BRASERO_MEDIUM_CAP_FALSE;
+	priv->dummy_sao = less_wrt_desc->dummy != 0;
+	priv->dummy_tao = less_wrt_desc->dummy != 0;
+	priv->burnfree = less_wrt_desc->buf != 0;
 	g_free (hdr);
-	return BRASERO_BURN_OK;
+	return TRUE;
 }
 
 /**
@@ -1046,13 +965,12 @@ brasero_medium_test_simulate_2A (BraseroMedium *self,
 
 	/* NOTE: this bit is only valid:
 	 * - for CDs when mode write is TAO or SAO
-	 * - for DVDs when mode write is incremental or SAO
-	 */
+	 * - for DVDs when mode write is incremental or SAO */
 
 	page_2A = (BraseroScsiStatusPage *) &data->page;
-	priv->dummy_sao = page_2A->dummy ? BRASERO_MEDIUM_CAP_TRUE:BRASERO_MEDIUM_CAP_FALSE;
-	priv->dummy_tao = page_2A->dummy ? BRASERO_MEDIUM_CAP_TRUE:BRASERO_MEDIUM_CAP_FALSE;
-	priv->burnfree = page_2A->buffer ? BRASERO_MEDIUM_CAP_TRUE:BRASERO_MEDIUM_CAP_FALSE;
+	priv->dummy_sao = page_2A->dummy != 0;
+	priv->dummy_tao = page_2A->dummy != 0;
+	priv->burnfree = page_2A->buffer != 0;
 	g_free (data);
 }
 
@@ -1101,7 +1019,7 @@ brasero_medium_init_caps (BraseroMedium *self,
  * Function to retrieve the capacity of a media
  */
 
-static BraseroBurnResult
+static gboolean
 brasero_medium_get_capacity_CD_RW (BraseroMedium *self,
 				   BraseroDeviceHandle *handle,
 				   BraseroScsiErrCode *code)
@@ -1122,7 +1040,7 @@ brasero_medium_get_capacity_CD_RW (BraseroMedium *self,
 
 	if (result != BRASERO_SCSI_OK) {
 		BRASERO_MEDIA_LOG ("READ ATIP failed (scsi error)");
-		return BRASERO_BURN_ERR;
+		return FALSE;
 	}
 
 	/* check the size of the structure: it must be at least 16 bytes long */
@@ -1131,7 +1049,7 @@ brasero_medium_get_capacity_CD_RW (BraseroMedium *self,
 			g_free (atip_data);
 
 		BRASERO_MEDIA_LOG ("READ ATIP failed (wrong size)");
-		return BRASERO_BURN_ERR;
+		return FALSE;
 	}
 
 	priv->block_num = BRASERO_MSF_TO_LBA (atip_data->desc->leadout_mn,
@@ -1143,10 +1061,10 @@ brasero_medium_get_capacity_CD_RW (BraseroMedium *self,
 			   priv->block_num,
 			   priv->block_size);
 
-	return BRASERO_BURN_OK;
+	return TRUE;
 }
 
-static BraseroBurnResult
+static gboolean
 brasero_medium_get_capacity_DVD_RW (BraseroMedium *self,
 				    BraseroDeviceHandle *handle,
 				    BraseroScsiErrCode *code)
@@ -1167,10 +1085,8 @@ brasero_medium_get_capacity_DVD_RW (BraseroMedium *self,
 						      &size,
 						      code);
 	if (result != BRASERO_SCSI_OK) {
-		g_free (hdr);
-
 		BRASERO_MEDIA_LOG ("READ FORMAT CAPACITIES failed");
-		return BRASERO_BURN_ERR;
+		return FALSE;
 	}
 
 	/* NOTE: for BD-RE there is a slight problem to determine the exact
@@ -1242,10 +1158,10 @@ end:
 			  priv->block_size);
 
 	g_free (hdr);
-	return BRASERO_BURN_OK;
+	return TRUE;
 }
 
-static BraseroBurnResult
+static gboolean
 brasero_medium_get_capacity_by_type (BraseroMedium *self,
 				     BraseroDeviceHandle *handle,
 				     BraseroScsiErrCode *code)
@@ -1258,26 +1174,26 @@ brasero_medium_get_capacity_by_type (BraseroMedium *self,
 	priv->block_size = 2048;
 
 	if (!(priv->info & BRASERO_MEDIUM_REWRITABLE))
-		return BRASERO_BURN_OK;
+		return TRUE;
 
 	if (priv->info & BRASERO_MEDIUM_CD)
 		brasero_medium_get_capacity_CD_RW (self, handle, code);
 	else	/* Works for BD-RE as well */
 		brasero_medium_get_capacity_DVD_RW (self, handle, code);
 
-	return BRASERO_BURN_OK;
+	return TRUE;
 }
 
 /**
  * Functions to retrieve the speed
  */
 
-static BraseroBurnResult
+static gboolean
 brasero_medium_get_speed_mmc3 (BraseroMedium *self,
 			       BraseroDeviceHandle *handle,
 			       BraseroScsiErrCode *code)
 {
-	int size;
+	int size = 0;
 	int num_desc, i;
 	gint max_rd, max_wrt;
 	BraseroScsiResult result;
@@ -1296,28 +1212,49 @@ brasero_medium_get_speed_mmc3 (BraseroMedium *self,
 							    code);
 
 	if (result != BRASERO_SCSI_OK) {
-		g_free (wrt_perf);
-
 		BRASERO_MEDIA_LOG ("GET PERFORMANCE failed");
-		return BRASERO_BURN_ERR;
+		return FALSE;
 	}
 
-	num_desc = (size - sizeof (BraseroScsiGetPerfHdr)) /
-		    sizeof (BraseroScsiWrtSpdDesc);
+	BRASERO_MEDIA_LOG ("Successfully retrieved a header: size %d, address %p", size, wrt_perf);
 
-	if (num_desc <=  0)
+	/* Choose the smallest value for size */
+	size = MIN (size, BRASERO_GET_32 (wrt_perf->hdr.len) + sizeof (wrt_perf->hdr.len));
+	BRASERO_MEDIA_LOG ("Updated header size = %d", size);
+
+	/* NOTE: I don't know why but on some architecture/with some compilers
+	 * when size < sizeof (BraseroScsiGetPerfHdr) the whole operation below
+	 * is treated as signed which leads to have an outstanding number of 
+	 * descriptors instead of a negative one. So be anal when checking. */
+	if (size <= (sizeof (BraseroScsiGetPerfHdr) + sizeof (BraseroScsiWrtSpdDesc))) {
+		BRASERO_MEDIA_LOG ("No descriptors");
+		goto end;
+	}
+
+	/* Calculate the number of descriptors */
+	num_desc = (size - sizeof (BraseroScsiGetPerfHdr)) / sizeof (BraseroScsiWrtSpdDesc);
+	BRASERO_MEDIA_LOG ("Got %d descriptor(s)", num_desc);
+
+	if (num_desc <= 0)
 		goto end; 
 
-	priv->rd_speeds = g_new0 (gint, num_desc + 1);
-	priv->wr_speeds = g_new0 (gint, num_desc + 1);
+	priv->rd_speeds = g_new0 (guint, num_desc + 1);
+	priv->wr_speeds = g_new0 (guint, num_desc + 1);
 
 	max_rd = 0;
 	max_wrt = 0;
 
 	desc = (BraseroScsiWrtSpdDesc*) &wrt_perf->data;
-	for (i = 0; i < num_desc; i ++, desc ++) {
-		priv->rd_speeds [i] = BRASERO_GET_32 (desc->rd_speed);
-		priv->wr_speeds [i] = BRASERO_GET_32 (desc->wr_speed);
+
+	for (i = 0; i < num_desc; i ++) {
+		BRASERO_MEDIA_LOG ("Descriptor n° %d, address = %p", i, (desc + i));
+
+		priv->rd_speeds [i] = BRASERO_GET_32 (desc [i].rd_speed);
+		priv->wr_speeds [i] = BRASERO_GET_32 (desc [i].wr_speed);
+
+		BRASERO_MEDIA_LOG ("RD = %u / WRT = %u",
+				   priv->rd_speeds [i],
+				   priv->wr_speeds [i]);
 
 		max_rd = MAX (max_rd, priv->rd_speeds [i]);
 		max_wrt = MAX (max_wrt, priv->wr_speeds [i]);
@@ -1336,12 +1273,12 @@ end:
 	 * function but don't report any speed. So if our top speed is 0 then
 	 * use the other way to get the speed. It was a Teac */
 	if (!priv->max_wrt)
-		return BRASERO_BURN_ERR;
+		return FALSE;
 
-	return BRASERO_BURN_OK;
+	return TRUE;
 }
 
-static BraseroBurnResult
+static gboolean
 brasero_medium_get_page_2A_write_speed_desc (BraseroMedium *self,
 					     BraseroDeviceHandle *handle,
 					     BraseroScsiErrCode *code)
@@ -1365,35 +1302,39 @@ brasero_medium_get_page_2A_write_speed_desc (BraseroMedium *self,
 						   &size,
 						   code);
 	if (result != BRASERO_SCSI_OK) {
-		g_free (data);
-
 		BRASERO_MEDIA_LOG ("MODE SENSE failed");
-		return BRASERO_BURN_ERR;
+		return FALSE;
 	}
 
 	page_2A = (BraseroScsiStatusPage *) &data->page;
 
-	if (size < 18) {
+	/* Reminder: size = sizeof (BraseroScsiStatusPage) + sizeof (BraseroScsiModeHdr) */
+ 	size = MIN (size, sizeof (data->hdr.len) + BRASERO_GET_16 (data->hdr.len));
+
+	if (size < (G_STRUCT_OFFSET (BraseroScsiStatusPage, copy_mngt_rev) + sizeof (BraseroScsiModeHdr))) {
 		g_free (data);
 		BRASERO_MEDIA_LOG ("wrong page size");
-		return BRASERO_BURN_ERR;
+		return FALSE;
 	}
 
 	priv->max_rd = BRASERO_GET_16 (page_2A->rd_max_speed);
 	priv->max_wrt = BRASERO_GET_16 (page_2A->wr_max_speed);
 
-	/* Check if we can use the speed descriptors; if not use maximum */
-	if (size < 20) {
+	/* Check if we can use the speed descriptors. There must be at least one
+	 * available; if not use maximum speed member. */
+	if (size < (G_STRUCT_OFFSET (BraseroScsiStatusPage, wr_spd_desc) +
+		    sizeof (BraseroScsiModeHdr) +
+		    sizeof (BraseroScsiWrtSpdDesc))) {
 		BRASERO_MEDIA_LOG ("Maximum Speed (Page 2A [old]) %i", priv->max_wrt);
 
 		/* also add fake speed descriptors */
-		priv->wr_speeds = g_new0 (gint, 2);
+		priv->wr_speeds = g_new0 (guint, 2);
 		priv->wr_speeds [0] = BRASERO_GET_16 (page_2A->wr_max_speed);
-		priv->rd_speeds = g_new0 (gint, 2);
+		priv->rd_speeds = g_new0 (guint, 2);
 		priv->rd_speeds [0] = BRASERO_GET_16 (page_2A->rd_max_speed);
 
 		g_free (data);
-		return BRASERO_BURN_OK;
+		return TRUE;
 	}
 
 	desc_num = BRASERO_GET_16 (page_2A->wr_speed_desc_num);
@@ -1408,10 +1349,11 @@ brasero_medium_get_page_2A_write_speed_desc (BraseroMedium *self,
 	if (desc_num > max_num)
 		desc_num = max_num;
 
-	priv->wr_speeds = g_new0 (gint, desc_num + 1);
+	priv->wr_speeds = g_new0 (guint, desc_num + 1);
+
 	desc = page_2A->wr_spd_desc;
-	for (i = 0; i < desc_num; i ++, desc ++) {
-		priv->wr_speeds [i] = BRASERO_GET_16 (desc->speed);
+	for (i = 0; i < desc_num; i ++) {
+		priv->wr_speeds [i] = BRASERO_GET_16 (desc [i].speed);
 		max_wrt = MAX (max_wrt, priv->wr_speeds [i]);
 	}
 
@@ -1421,10 +1363,10 @@ brasero_medium_get_page_2A_write_speed_desc (BraseroMedium *self,
 	BRASERO_MEDIA_LOG ("Maximum Speed (Page 2A) %i", priv->max_wrt);
 	g_free (data);
 
-	return BRASERO_BURN_OK;
+	return TRUE;
 }
 
-static BraseroBurnResult
+static gboolean
 brasero_medium_get_speed (BraseroMedium *self,
 			  BraseroDeviceHandle *handle,
 			  BraseroScsiErrCode *code)
@@ -1434,7 +1376,7 @@ brasero_medium_get_speed (BraseroMedium *self,
 	BRASERO_MEDIA_LOG ("Retrieving media available speeds");
 
 	result = brasero_medium_get_speed_mmc3 (self, handle, code);
-	if (result == BRASERO_BURN_OK)
+	if (result == TRUE)
 		return result;
 
 	/* Fallback */
@@ -1446,19 +1388,19 @@ brasero_medium_get_speed (BraseroMedium *self,
  * Functions to get information about disc contents
  */
 
-static BraseroBurnResult
+static gboolean
 brasero_medium_track_volume_size (BraseroMedium *self,
 				  BraseroMediumTrack *track,
 				  BraseroDeviceHandle *handle)
 {
 	BraseroMediumPrivate *priv;
-	BraseroBurnResult res;
+	gboolean res;
 	GError *error = NULL;
 	BraseroVolSrc *vol;
 	gint64 nb_blocks;
 
 	if (!track)
-		return BRASERO_BURN_ERR;
+		return FALSE;
 
 	priv = BRASERO_MEDIUM_PRIVATE (self);
 
@@ -1486,11 +1428,11 @@ brasero_medium_track_volume_size (BraseroMedium *self,
 		if (error)
 			g_error_free (error);
 
-		return BRASERO_BURN_ERR;
+		return FALSE;
 	}
 
 	track->blocks_num = nb_blocks;
-	return BRASERO_BURN_OK;
+	return TRUE;
 }
 
 static gboolean
@@ -1548,7 +1490,7 @@ brasero_medium_track_written_SAO (BraseroDeviceHandle *handle,
 	return TRUE;
 }
 
-static BraseroBurnResult
+static gboolean
 brasero_medium_track_get_info (BraseroMedium *self,
 			       gboolean multisession,
 			       BraseroMediumTrack *track,
@@ -1583,7 +1525,7 @@ brasero_medium_track_get_info (BraseroMedium *self,
 
 	if (result != BRASERO_SCSI_OK) {
 		BRASERO_MEDIA_LOG ("READ TRACK INFO failed");
-		return BRASERO_BURN_ERR;
+		return FALSE;
 	}
 
 	track->blocks_num = BRASERO_GET_32 (track_info.track_size);
@@ -1673,10 +1615,10 @@ brasero_medium_track_get_info (BraseroMedium *self,
 			  track->start,
 			  track->blocks_num);
 
-	return BRASERO_BURN_OK;
+	return TRUE;
 }
 
-static BraseroBurnResult
+static gboolean
 brasero_medium_track_set_leadout_DVDR_blank (BraseroMedium *self,
 					     BraseroDeviceHandle *handle,
 					     BraseroMediumTrack *leadout,
@@ -1700,10 +1642,8 @@ brasero_medium_track_set_leadout_DVDR_blank (BraseroMedium *self,
 						      &size,
 						      code);
 	if (result != BRASERO_SCSI_OK) {
-		g_free (hdr);
-
 		BRASERO_MEDIA_LOG ("READ FORMAT CAPACITIES failed");
-		return BRASERO_BURN_ERR;
+		return FALSE;
 	}
 
 	/* See if the media is already formatted which means for -R media that 
@@ -1712,7 +1652,7 @@ brasero_medium_track_set_leadout_DVDR_blank (BraseroMedium *self,
 	if (current->type & BRASERO_SCSI_DESC_FORMATTED) {
 		BRASERO_MEDIA_LOG ("Unformatted medium");
 		g_free (hdr);
-		return BRASERO_BURN_ERR;
+		return FALSE;
 	}
 		
 	BRASERO_MEDIA_LOG ("Unformatted medium");
@@ -1726,10 +1666,10 @@ brasero_medium_track_set_leadout_DVDR_blank (BraseroMedium *self,
 			  leadout->blocks_num);
 
 	g_free (hdr);
-	return BRASERO_BURN_OK;
+	return TRUE;
 }
 
-static BraseroBurnResult
+static gboolean
 brasero_medium_track_set_leadout_CDR_blank (BraseroMedium *self,
 					    BraseroDeviceHandle *handle,
 					    BraseroMediumTrack *leadout,
@@ -1750,7 +1690,7 @@ brasero_medium_track_set_leadout_CDR_blank (BraseroMedium *self,
 	result = brasero_mmc1_read_atip (handle, &atip, &size, code);
 	if (result != BRASERO_SCSI_OK) {
 		BRASERO_MEDIA_LOG ("READ ATIP failed");
-		return BRASERO_BURN_ERR;
+		return FALSE;
 	}
 
 	leadout->blocks_num = atip->desc->leadout_mn * 60 * 75 +
@@ -1766,10 +1706,10 @@ brasero_medium_track_set_leadout_CDR_blank (BraseroMedium *self,
 
 	g_free (atip);
 
-	return BRASERO_BURN_OK;
+	return TRUE;
 }
 
-static BraseroBurnResult
+static gboolean
 brasero_medium_set_write_mode_page (BraseroMedium *self,
 				    BraseroDeviceHandle *handle,
 				    BraseroScsiErrCode *code)
@@ -1830,19 +1770,19 @@ brasero_medium_set_write_mode_page (BraseroMedium *self,
 			BRASERO_MEDIA_LOG ("MODE SELECT failed");
 
 			/* This isn't necessarily a problem! we better try */
-			return BRASERO_BURN_ERR;
+			return FALSE;
 		}
 	}
 	else {
 		BRASERO_MEDIA_LOG ("MODE SENSE failed");
 		/* This isn't necessarily a problem! we better try the rest */
-		return BRASERO_BURN_ERR;
+		return FALSE;
 	}
 
-	return BRASERO_BURN_OK;
+	return TRUE;
 }
 
-static BraseroBurnResult
+static gboolean
 brasero_medium_track_set_leadout (BraseroMedium *self,
 				  BraseroDeviceHandle *handle,
 				  BraseroMediumTrack *leadout,
@@ -1860,7 +1800,7 @@ brasero_medium_track_set_leadout (BraseroMedium *self,
 
 	if (BRASERO_MEDIUM_RANDOM_WRITABLE (priv->info)) {
 		BRASERO_MEDIA_LOG ("Overwritable medium  => skipping");
-		return BRASERO_BURN_OK;
+		return TRUE;
 	}
 
 	if (BRASERO_MEDIUM_IS (priv->info, BRASERO_MEDIUM_CDR)) {
@@ -1870,7 +1810,7 @@ brasero_medium_track_set_leadout (BraseroMedium *self,
 		 * This can work with CD-R/W and DVD-R/W. + media don't use the
 		 * write mode page anyway. */
 		result = brasero_medium_set_write_mode_page (self, handle, code);
-		if (result == BRASERO_BURN_ERR
+		if (result == FALSE
 		&&  BRASERO_MEDIUM_IS (priv->info, BRASERO_MEDIUM_CDR|BRASERO_MEDIUM_BLANK))
 			return brasero_medium_track_set_leadout_CDR_blank (self,
 									   handle,
@@ -1897,7 +1837,7 @@ brasero_medium_track_set_leadout (BraseroMedium *self,
 		track_num = priv->first_open_track;
 	else {
 		BRASERO_MEDIA_LOG ("There aren't any open session set");
-		return BRASERO_BURN_ERR;
+		return FALSE;
 	}
 
 	result = brasero_mmc1_read_track_info (handle,
@@ -1920,7 +1860,7 @@ brasero_medium_track_set_leadout (BraseroMedium *self,
 									    leadout,
 									    code);
 			 
-		return BRASERO_BURN_ERR;
+		return FALSE;
 	}
 
 	BRASERO_MEDIA_LOG ("Next Writable Address is %d", BRASERO_GET_32 (track_info.next_wrt_address));
@@ -1949,7 +1889,7 @@ brasero_medium_track_set_leadout (BraseroMedium *self,
 			  leadout->start,
 			  leadout->blocks_num);
 
-	return BRASERO_BURN_OK;
+	return TRUE;
 }
 
 /**
@@ -2001,7 +1941,7 @@ brasero_medium_add_DVD_plus_RW_leadout (BraseroMedium *self)
 			  leadout->blocks_num);
 }
 
-static BraseroBurnResult
+static gboolean
 brasero_medium_get_sessions_info (BraseroMedium *self,
 				  BraseroDeviceHandle *handle,
 				  BraseroScsiErrCode *code)
@@ -2022,10 +1962,8 @@ brasero_medium_get_sessions_info (BraseroMedium *self,
 						  &size,
 						  code);
 	if (result != BRASERO_SCSI_OK) {
-		g_free (toc);
-
 		BRASERO_MEDIA_LOG ("READ TOC failed");
-		return BRASERO_BURN_ERR;
+		return FALSE;
 	}
 
 	num = (size - sizeof (BraseroScsiFormattedTocData)) /
@@ -2046,7 +1984,7 @@ brasero_medium_get_sessions_info (BraseroMedium *self,
 
 		if (desc->track_num == BRASERO_SCSI_TRACK_LEADOUT_START) {
 			BRASERO_MEDIA_LOG ("Leadout reached %d",
-					  BRASERO_GET_32 (desc->track_start));
+					   BRASERO_GET_32 (desc->track_start));
 			break;
 		}
 
@@ -2077,7 +2015,7 @@ brasero_medium_get_sessions_info (BraseroMedium *self,
 		}
 
 		if (BRASERO_MEDIUM_RANDOM_WRITABLE (priv->info)) {
-			BraseroBurnResult result;
+			gboolean result;
 
 			/* A special case for these kinds of media (DVD+RW, ...)
 			 * which have only one track: the first. Since it's not
@@ -2089,7 +2027,7 @@ brasero_medium_get_sessions_info (BraseroMedium *self,
 			result = brasero_medium_track_volume_size (self, 
 								   track,
 								   handle);
-			if (result != BRASERO_BURN_OK) {
+			if (result != TRUE) {
 				priv->tracks = g_slist_remove (priv->tracks, track);
 				g_free (track);
 
@@ -2114,7 +2052,7 @@ brasero_medium_get_sessions_info (BraseroMedium *self,
 
 		if (priv->probe_cancelled) {
 			g_free (toc);
-			return BRASERO_BURN_CANCEL;
+			return FALSE;
 		}
 
 		brasero_medium_track_get_info (self,
@@ -2127,7 +2065,7 @@ brasero_medium_get_sessions_info (BraseroMedium *self,
 
 	if (priv->probe_cancelled) {
 		g_free (toc);
-		return BRASERO_BURN_CANCEL;
+		return FALSE;
 	}
 
 	/* put the tracks in the right order */
@@ -2153,7 +2091,7 @@ brasero_medium_get_sessions_info (BraseroMedium *self,
 
 	g_free (toc);
 
-	return BRASERO_BURN_OK;
+	return TRUE;
 }
 
 static void
@@ -2184,7 +2122,7 @@ brasero_medium_get_DVD_id (BraseroMedium *self,
 	g_free (hdr);
 }
 
-static BraseroBurnResult
+static gboolean
 brasero_medium_set_blank (BraseroMedium *self,
 			  BraseroDeviceHandle *handle,
 			  gint first_open_track,
@@ -2217,16 +2155,16 @@ brasero_medium_set_blank (BraseroMedium *self,
 						  code);
 	}
 
-	return BRASERO_BURN_OK;
+	return TRUE;
 }
 
-static BraseroBurnResult
+static gboolean
 brasero_medium_get_contents (BraseroMedium *self,
 			     BraseroDeviceHandle *handle,
 			     BraseroScsiErrCode *code)
 {
 	int size;
-	BraseroBurnResult res;
+	gboolean res;
 	BraseroScsiResult result;
 	BraseroMediumPrivate *priv;
 	BraseroScsiDiscInfoStd *info = NULL;
@@ -2240,10 +2178,8 @@ brasero_medium_get_contents (BraseroMedium *self,
 							 &size,
 							 code);
 	if (result != BRASERO_SCSI_OK) {
-		g_free (info);
-	
 		BRASERO_MEDIA_LOG ("READ DISC INFORMATION failed");
-		return BRASERO_BURN_ERR;
+		return FALSE;
 	}
 
 	if (info->disc_id_valid) {
@@ -2300,7 +2236,7 @@ brasero_medium_get_contents (BraseroMedium *self,
  * Some identification functions
  */
 
-static BraseroBurnResult
+static gboolean
 brasero_medium_get_medium_type (BraseroMedium *self,
 				BraseroDeviceHandle *handle,
 				BraseroScsiErrCode *code)
@@ -2332,8 +2268,9 @@ brasero_medium_get_medium_type (BraseroMedium *self,
 
 		/* If this fails it means that this drive is probably older than
 		 * MMC1 spec or does not conform to it. */
-		if (result != BRASERO_BURN_OK)
-			return BRASERO_BURN_ERR;
+		if (result != TRUE)
+		if (result != TRUE)
+			return FALSE;
 
 		/* The only thing here left to determine is if that's a WRITABLE
 		 * or a REWRITABLE. To determine that information, we need to
@@ -2356,7 +2293,7 @@ brasero_medium_get_medium_type (BraseroMedium *self,
 					g_free (data);
 
 				BRASERO_MEDIA_LOG ("READ ATIP failed (wrong size)");
-				return BRASERO_BURN_ERR;
+				return FALSE;
 			}
 
 			if (data->desc->erasable) {
@@ -2481,7 +2418,7 @@ brasero_medium_get_medium_type (BraseroMedium *self,
 	case BRASERO_SCSI_PROF_HD_DVD_R:
 	case BRASERO_SCSI_PROF_HD_DVD_RAM:
 		priv->info = BRASERO_MEDIUM_UNSUPPORTED;
-		return BRASERO_BURN_NOT_SUPPORTED;
+		return FALSE;
 	}
 
 	/* Get a more precise idea of what sequential BD-R type we have here */
@@ -2532,10 +2469,10 @@ brasero_medium_get_medium_type (BraseroMedium *self,
 		/* FIXME: check for dual layer BD */
 	}
 
-	return BRASERO_BURN_OK;
+	return TRUE;
 }
 
-static BraseroBurnResult
+static gboolean
 brasero_medium_get_css_feature (BraseroMedium *self,
 				BraseroDeviceHandle *handle,
 				BraseroScsiErrCode *code)
@@ -2554,15 +2491,13 @@ brasero_medium_get_css_feature (BraseroMedium *self,
 							 &size,
 							 code);
 	if (result != BRASERO_SCSI_OK) {
-		g_free (hdr);
-
 		BRASERO_MEDIA_LOG ("GET CONFIGURATION failed");
-		return BRASERO_BURN_ERR;
+		return FALSE;
 	}
 
 	if (hdr->desc->add_len < sizeof (BraseroScsiDVDCssDesc)) {
 		g_free (hdr);
-		return BRASERO_BURN_OK;
+		return TRUE;
 	}
 
 	/* here we just need to see if this feature is current or not */
@@ -2572,7 +2507,7 @@ brasero_medium_get_css_feature (BraseroMedium *self,
 	}
 
 	g_free (hdr);
-	return BRASERO_BURN_OK;
+	return TRUE;
 }
 
 static gboolean
@@ -2850,7 +2785,7 @@ brasero_medium_init_real (BraseroMedium *object,
 {
 	guint i;
 	gchar *name;
-	BraseroBurnResult result;
+	gboolean result;
 	BraseroMediumPrivate *priv;
 	BraseroScsiErrCode code = 0;
 	gchar buffer [256] = { 0, };
@@ -2865,14 +2800,16 @@ brasero_medium_init_real (BraseroMedium *object,
 		return;
 
 	result = brasero_medium_get_medium_type (object, handle, &code);
-	if (result != BRASERO_BURN_OK)
+	if (result != TRUE)
+	if (result != TRUE)
 		return;
 
 	if (priv->probe_cancelled)
 		return;
 
 	result = brasero_medium_get_speed (object, handle, &code);
-	if (result != BRASERO_BURN_OK)
+	if (result != TRUE)
+	if (result != TRUE)
 		return;
 
 	if (priv->probe_cancelled)
@@ -2883,7 +2820,8 @@ brasero_medium_init_real (BraseroMedium *object,
 		return;
 
 	result = brasero_medium_get_contents (object, handle, &code);
-	if (result != BRASERO_BURN_OK)
+	if (result != TRUE)
+	if (result != TRUE)
 		return;
 
 	if (priv->probe_cancelled)
@@ -2937,6 +2875,9 @@ brasero_medium_probed (gpointer data)
 
 	priv = BRASERO_MEDIUM_PRIVATE (data);
 
+	g_thread_join (priv->probe);
+	priv->probe = NULL;
+
 	/* This signal must be emitted in the main thread */
 	GDK_THREADS_ENTER ();
 	g_signal_emit (data,
@@ -3009,7 +2950,6 @@ brasero_medium_probe_thread (gpointer self)
 		BRASERO_MEDIA_LOG ("Open () failed: medium busy");
 
 	priv->probe_id = g_idle_add (brasero_medium_probed, self);
-	priv->probe = NULL;
 	return NULL;
 }
 
@@ -3303,6 +3243,38 @@ brasero_medium_can_be_rewritten (BraseroMedium *medium)
 
 	return FALSE;
 }
+gboolean
+brasero_medium_can_use_dummy_for_sao (BraseroMedium *medium)
+{
+	BraseroMediumPrivate *priv;
+
+	g_return_val_if_fail (BRASERO_IS_MEDIUM (medium), FALSE);
+
+	priv = BRASERO_MEDIUM_PRIVATE (medium);
+	return priv->dummy_sao;
+}
+
+gboolean
+brasero_medium_can_use_dummy_for_tao (BraseroMedium *medium)
+{
+	BraseroMediumPrivate *priv;
+
+	g_return_val_if_fail (BRASERO_IS_MEDIUM (medium), FALSE);
+
+	priv = BRASERO_MEDIUM_PRIVATE (medium);
+	return priv->dummy_tao;
+}
+
+gboolean
+brasero_medium_can_use_burnfree (BraseroMedium *medium)
+{
+	BraseroMediumPrivate *priv;
+
+	g_return_val_if_fail (BRASERO_IS_MEDIUM (medium), FALSE);
+
+	priv = BRASERO_MEDIUM_PRIVATE (medium);
+	return priv->burnfree;
+}
 
 /**
  * brasero_medium_get_drive:
