@@ -24,6 +24,8 @@
 #include <glib.h>
 #include <glib/gi18n-lib.h>
 
+#include "brasero-tags.h"
+
 #include "brasero-video-project.h"
 #include "brasero-file-monitor.h"
 #include "brasero-io.h"
@@ -35,7 +37,6 @@ struct _BraseroVideoProjectPrivate
 	guint ref_count;
 	GHashTable *references;
 
-	BraseroIO *io;
 	BraseroIOJobBase *load_uri;
 	BraseroIOJobBase *load_dir;
 
@@ -208,10 +209,12 @@ brasero_video_project_rename (BraseroVideoProject *self,
 	gchar *tmp;
 	BraseroVideoProjectClass *klass;
 
-	tmp = file->name;
-	file->name = g_strdup (name);
+	tmp = file->info->title;
+	file->info->title = g_strdup (name);
 	g_free (tmp);
 
+	file->title_set = TRUE;
+
 	klass = BRASERO_VIDEO_PROJECT_GET_CLASS (self);
 	if (klass->node_changed)
 		klass->node_changed (self, file);
@@ -297,7 +300,7 @@ brasero_video_file_free (BraseroVideoFile *file)
 		g_object_unref (file->snapshot);
 
 	if (file->info)
-		brasero_song_info_free (file->info);
+		brasero_stream_info_free (file->info);
 
 	g_free (file);
 }
@@ -375,13 +378,14 @@ brasero_video_project_reset (BraseroVideoProject *self)
 	priv = BRASERO_VIDEO_PROJECT_PRIVATE (self);
 
 	/* cancel all VFS operations */
-	if (priv->io) {
-		brasero_io_cancel_by_base (priv->io, priv->load_uri);
-		brasero_io_cancel_by_base (priv->io, priv->load_dir);
-
+	if (priv->load_uri) {
+		brasero_io_cancel_by_base (priv->load_uri);
 		g_free (priv->load_uri);
 		priv->load_uri = NULL;
+	}
 
+	if (priv->load_dir) {
+		brasero_io_cancel_by_base (priv->load_dir);
 		g_free (priv->load_dir);
 		priv->load_dir = NULL;
 	}
@@ -476,7 +480,6 @@ brasero_video_project_set_file_information (BraseroVideoProject *self,
 {
 	guint64 len;
 	GdkPixbuf *snapshot;
-	BraseroSongInfo *song;
 	BraseroVideoProjectPrivate *priv;
 
 	priv = BRASERO_VIDEO_PROJECT_PRIVATE (self);
@@ -500,31 +503,53 @@ brasero_video_project_set_file_information (BraseroVideoProject *self,
 	}
 
 	/* Set the snapshot */
-	snapshot = GDK_PIXBUF (g_file_info_get_attribute_object (info, BRASERO_IO_SNAPSHOT));
+	snapshot = GDK_PIXBUF (g_file_info_get_attribute_object (info, BRASERO_IO_THUMBNAIL));
 	if (snapshot) {
 		GdkPixbuf *scaled;
 
 		scaled = gdk_pixbuf_scale_simple (snapshot,
-						  96 * gdk_pixbuf_get_width (snapshot) / gdk_pixbuf_get_height (snapshot),
-						  96,
+						  48 * gdk_pixbuf_get_width (snapshot) / gdk_pixbuf_get_height (snapshot),
+						  48,
 						  GDK_INTERP_BILINEAR);
 		file->snapshot = scaled;
 	}
 
 	/* size */
-	len = g_file_info_get_attribute_uint64 (info, BRASERO_IO_LEN);
-	if (file->end > len)
-		file->end = len;
-	else if (file->end <= 0)
-		file->end = len;
+	if (!file->len_set) {
+		len = g_file_info_get_attribute_uint64 (info, BRASERO_IO_LEN);
+		if (file->end > len)
+			file->end = len;
+		else if (file->end <= 0)
+			file->end = len;
+	}
 
 	/* Get the song info */
-	song = g_new0 (BraseroSongInfo, 1);
-	song->title = g_strdup (g_file_info_get_attribute_string (info, BRASERO_IO_TITLE));
-	song->artist = g_strdup (g_file_info_get_attribute_string (info, BRASERO_IO_ARTIST));
-	song->composer = g_strdup (g_file_info_get_attribute_string (info, BRASERO_IO_COMPOSER));
-	song->isrc = g_file_info_get_attribute_int32 (info, BRASERO_IO_ISRC);
-	file->info = song;
+	if (!file->info)
+		file->info = g_new0 (BraseroStreamInfo, 1);
+
+	if (!file->title_set) {
+		if (file->info->title)
+			g_free (file->info->title);
+
+		file->info->title = g_strdup (g_file_info_get_attribute_string (info, BRASERO_IO_TITLE));
+	}
+
+	if (!file->artist_set) {
+		if (file->info->artist)
+			g_free (file->info->artist);
+
+		file->info->artist = g_strdup (g_file_info_get_attribute_string (info, BRASERO_IO_ARTIST));
+	}
+
+	if (!file->composer_set) {
+		if (file->info->composer)
+			g_free (file->info->composer);
+
+		file->info->composer = g_strdup (g_file_info_get_attribute_string (info, BRASERO_IO_COMPOSER));
+	}
+
+	if (!file->isrc_set)
+		file->info->isrc = g_file_info_get_attribute_int32 (info, BRASERO_IO_ISRC);
 
 #ifdef BUILD_INOTIFY
 
@@ -607,9 +632,6 @@ brasero_video_project_add_directory_contents (BraseroVideoProject *self,
 
 	priv = BRASERO_VIDEO_PROJECT_PRIVATE (self);
 
-	if (!priv->io)
-		priv->io = brasero_io_get_default ();
-
 	if (!priv->load_dir)
 		priv->load_dir = brasero_io_register (G_OBJECT (self),
 						      brasero_video_project_add_directory_contents_result,
@@ -624,15 +646,14 @@ brasero_video_project_add_directory_contents (BraseroVideoProject *self,
 
 	ref = brasero_video_project_reference_new (self, sibling);
 
-	brasero_io_load_directory (priv->io,
-				   uri,
+	brasero_io_load_directory (uri,
 				   priv->load_dir,
 				   BRASERO_IO_INFO_MIME|
 				   BRASERO_IO_INFO_PERM|
 				   BRASERO_IO_INFO_METADATA|
 				   BRASERO_IO_INFO_METADATA_MISSING_CODEC|
 				   BRASERO_IO_INFO_RECURSIVE|
-				   BRASERO_IO_INFO_METADATA_SNAPSHOT,
+				   BRASERO_IO_INFO_METADATA_THUMBNAIL,
 				   GINT_TO_POINTER (ref));
 }
 
@@ -718,6 +739,7 @@ brasero_video_project_result_cb (GObject *obj,
 BraseroVideoFile *
 brasero_video_project_add_uri (BraseroVideoProject *self,
 			       const gchar *uri,
+			       BraseroStreamInfo *info,
 			       BraseroVideoFile *sibling,
 			       gint64 start,
 			       gint64 end)
@@ -735,11 +757,28 @@ brasero_video_project_add_uri (BraseroVideoProject *self,
 	file = g_new0 (BraseroVideoFile, 1);
 	file->uri = g_strdup (uri);
 
+	if (info) {
+		file->info = brasero_stream_info_copy (info);
+
+		if (info->isrc)
+			file->isrc_set = TRUE;
+		if (info->title)
+			file->title_set = TRUE;
+		if (info->artist)
+			file->artist_set = TRUE;
+		if (info->composer)
+			file->composer_set = TRUE;
+	}
+	else
+		file->info = g_new0 (BraseroStreamInfo, 1);
+
 	if (start > -1)
 		file->start = start;
 
-	if (end > -1)
+	if (end > -1) {
 		file->end = end;
+		file->len_set = TRUE;
+	}
 
 	if (sibling) {
 		file->next = sibling;
@@ -775,9 +814,6 @@ brasero_video_project_add_uri (BraseroVideoProject *self,
 		klass->node_added (self, file);
 
 	/* get info async for the file */
-	if (!priv->io)
-		priv->io = brasero_io_get_default ();
-
 	if (!priv->load_uri)
 		priv->load_uri = brasero_io_register (G_OBJECT (self),
 						      brasero_video_project_result_cb,
@@ -788,15 +824,14 @@ brasero_video_project_add_uri (BraseroVideoProject *self,
 	priv->loading ++;
 
 	ref = brasero_video_project_reference_new (self, file);
-	brasero_io_get_file_info (priv->io,
-				  uri,
+	brasero_io_get_file_info (uri,
 				  priv->load_uri,
 				  BRASERO_IO_INFO_PERM|
 				  BRASERO_IO_INFO_MIME|
 				  BRASERO_IO_INFO_URGENT|
 				  BRASERO_IO_INFO_METADATA|
 				  BRASERO_IO_INFO_METADATA_MISSING_CODEC|
-				  BRASERO_IO_INFO_METADATA_SNAPSHOT,
+				  BRASERO_IO_INFO_METADATA_THUMBNAIL,
 				  GINT_TO_POINTER (ref));
 
 	g_signal_emit (self,
@@ -904,14 +939,23 @@ brasero_video_project_get_item_index (BraseroVideoProject *self,
 }
 
 BraseroDiscResult
-brasero_video_project_get_status (BraseroVideoProject *self)
+brasero_video_project_get_status (BraseroVideoProject *self,
+				  gint *remaining,
+				  gchar **current_task)
 {
 	BraseroVideoProjectPrivate *priv;
 
 	priv = BRASERO_VIDEO_PROJECT_PRIVATE (self);
 
-	if (priv->loading)
-		return BRASERO_DISC_LOADING;
+	if (priv->loading) {
+		if (remaining)
+			*remaining = priv->loading;
+
+		if (current_task)
+			*current_task = g_strdup (_("Analysing video files"));
+
+		return BRASERO_DISC_NOT_READY;
+	}
 
 	if (!priv->first)
 		return BRASERO_DISC_ERROR_EMPTY_SELECTION;
@@ -920,7 +964,8 @@ brasero_video_project_get_status (BraseroVideoProject *self)
 }
 
 GSList *
-brasero_video_project_get_contents (BraseroVideoProject *self)
+brasero_video_project_get_contents (BraseroVideoProject *self,
+				    gboolean values_set)
 {
 	GSList *tracks = NULL;
 	BraseroVideoFile *file;
@@ -931,25 +976,50 @@ brasero_video_project_get_contents (BraseroVideoProject *self)
 		return NULL;
 
 	for (file = priv->first; file; file = file->next) {
-		BraseroSongInfo *info = NULL;
-		BraseroTrack *track;
+		BraseroTrackStream *track;
 
-		if (file->info)
-			info = brasero_song_info_copy (file->info);
+		track = brasero_track_stream_new ();
+		brasero_track_stream_set_source (track, file->uri);
+		brasero_track_stream_set_format (track,
+						 BRASERO_AUDIO_FORMAT_UNDEFINED|
+						 BRASERO_VIDEO_FORMAT_UNDEFINED);
+
+		if (!values_set || file->len_set)
+			brasero_track_stream_set_boundaries (track,
+							     file->start,
+							     file->end,
+							     -1);
 		else
-			info = NULL;
+			brasero_track_stream_set_boundaries (track,
+							     file->start,
+							     0,
+							     -1);
 
-		track = brasero_track_new (BRASERO_TRACK_TYPE_AUDIO);
-		brasero_track_set_audio_source (track,
-						file->uri,
-						BRASERO_AUDIO_FORMAT_UNDEFINED|
-						BRASERO_VIDEO_FORMAT_UNDEFINED);
+		if (file->info && values_set) {
+			if (!file->title_set)
+				brasero_track_tag_add_string (BRASERO_TRACK (track),
+							      BRASERO_TRACK_STREAM_TITLE_TAG,
+							      file->info->title);
 
-		brasero_track_set_audio_boundaries (track, file->start, file->end, -1);
-		brasero_track_set_audio_info (track, info);
-		tracks = g_slist_prepend (tracks, track);
+			if (!file->artist_set)
+				brasero_track_tag_add_string (BRASERO_TRACK (track),
+							      BRASERO_TRACK_STREAM_ARTIST_TAG,
+							      file->info->artist);
+
+			if (!file->composer_set)
+				brasero_track_tag_add_string (BRASERO_TRACK (track),
+							      BRASERO_TRACK_STREAM_COMPOSER_TAG,
+							      file->info->composer);
+			if (!file->isrc_set)
+				brasero_track_tag_add_int (BRASERO_TRACK (track),
+							   BRASERO_TRACK_STREAM_ISRC_TAG,
+							   file->info->isrc);
+		}
+
+		tracks = g_slist_prepend (tracks, BRASERO_TRACK (track));
 	}
 
+	tracks = g_slist_reverse (tracks);
 	return tracks;
 }
 
@@ -973,7 +1043,7 @@ brasero_video_project_finalize (GObject *object)
 	for (iter = priv->first; iter; iter = next) {
 		next = iter->next;
 		g_free (iter->uri);
-		brasero_song_info_free (iter->info);
+		brasero_stream_info_free (iter->info);
 		g_free (iter);
 	}
 
@@ -1025,22 +1095,21 @@ brasero_video_project_file_modified (BraseroFileMonitor *monitor,
 
 	/* priv->load_uri has already been initialized otherwise the tree would
 	 * be empty. But who knows... */
-	if (!priv->io || !priv->load_uri)
+	if (!priv->load_uri)
 		return;
 
 	file = callback_data;
 	file->is_reloading = TRUE;
 
 	ref = brasero_video_project_reference_new (BRASERO_VIDEO_PROJECT (monitor), file);
-	brasero_io_get_file_info (priv->io,
-				  file->uri,
+	brasero_io_get_file_info (file->uri,
 				  priv->load_uri,
 				  BRASERO_IO_INFO_PERM|
 				  BRASERO_IO_INFO_MIME|
 				  BRASERO_IO_INFO_URGENT|
 				  BRASERO_IO_INFO_METADATA|
 				  BRASERO_IO_INFO_METADATA_MISSING_CODEC|
-				  BRASERO_IO_INFO_METADATA_SNAPSHOT,
+				  BRASERO_IO_INFO_METADATA_THUMBNAIL,
 				  GINT_TO_POINTER (ref));
 }
 
