@@ -48,8 +48,6 @@
 #include "brasero-utils.h"
 #include "brasero-app.h"
 
-#include "burn-debug.h"
-
 #include "brasero-burn-lib.h"
 #include "brasero-session.h"
 
@@ -70,7 +68,6 @@ gint disc_blank;
 gint disc_check;
 gint open_ncb;
 gint parent_window;
-gint debug;
 
 #define BRASERO_CONF_DIR "/apps/brasero"
 
@@ -139,10 +136,6 @@ static const GOptionEntry options [] = {
 	 * parent as if brasero was a dialog for the parent application */
 	  N_("The XID of the parent window"), NULL },
 
-	{ "debug", 'g', 0, G_OPTION_ARG_NONE, &debug,
-	  N_("Display debug statements on stdout"),
-	  NULL },
-
 	{ G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &files,
 	  NULL, NULL }, /* collects file arguments */
 
@@ -213,7 +206,7 @@ brasero_handle_burn_uri (BraseroApp *app,
 			string = g_strdup (_("An internal error occured"));
 
 		brasero_app_alert (app,
-				   _("Error while loading the project."),
+				   _("Error while loading the project"),
 				   string,
 				   GTK_MESSAGE_ERROR);
 
@@ -239,7 +232,7 @@ brasero_handle_burn_uri (BraseroApp *app,
 			string = g_strdup (_("An internal error occured"));
 
 		brasero_app_alert (app,
-				   _("Error while loading the project."),
+				   _("Error while loading the project"),
 				   string,
 				   GTK_MESSAGE_ERROR);
 
@@ -495,7 +488,6 @@ main (int argc, char **argv)
 	GConfClient *client;
 	GOptionContext *context;
 
-
 #ifdef ENABLE_NLS
 	bindtextdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
@@ -514,6 +506,7 @@ main (int argc, char **argv)
 	g_option_context_add_group (context, egg_sm_client_get_option_group ());
 	g_option_context_add_group (context, gtk_get_option_group (TRUE));
 	g_option_context_add_group (context, brasero_media_get_option_group ());
+	g_option_context_add_group (context, brasero_burn_library_get_option_group ());
 	g_option_context_add_group (context, gst_init_get_option_group ());
 	if (g_option_context_parse (context, &argc, &argv, NULL) == FALSE) {
 		g_print (_("Please type %s --help to see all available options\n"), argv [0]);
@@ -534,7 +527,6 @@ main (int argc, char **argv)
 			      GCONF_CLIENT_PRELOAD_NONE,
 			      NULL);
 
-	brasero_burn_set_debug (debug);
 	brasero_burn_library_start ();
 
 	brasero_enable_multi_DND ();
